@@ -107,9 +107,10 @@ public class gDialog {
 				     JOptionPane.PLAIN_MESSAGE);
 
 
-	if( i == JOptionPane.YES_OPTION) {
+	if( i == JOptionPane.YES_OPTION || 
+	    i == JOPtionPane.OK_OPTION) {
 	    return 1;
-	} else if ( i == JOptionPane.NO_OPTION) {
+	} else if ( i == JOptionPane.NO_OPTION)
 	    return 0;
 	} else if ( i == JOptionPane.CANCEL_OPTION) {
 	    return -1;
